@@ -18,7 +18,7 @@ from calculate.consolegui import qt
 import urllib2
 import OpenSSL, hashlib
 
-from more import show_msg, LabelWordWrap, show_question, get_ip_mac
+from more import show_msg, LabelWordWrap, show_question, get_ip_mac, get_icon
 from create_cert import RequestCreate
 from client_class import HTTPSClientCertTransport, Client_suds
 import os
@@ -88,7 +88,7 @@ class CertClass (qt.QWidget):
                   - self.size().height() / 2 - 50)  
 
         self.setWindowTitle (_('Certificates'))
-        self.setWindowIcon (qt.QIcon.fromTheme("view-certificate"))
+        self.setWindowIcon (get_icon("view-certificate"))
 
     def send(self):
     ### client_post_request analog
@@ -243,7 +243,7 @@ class CertClass (qt.QWidget):
             return 1
 
         if not os.path.exists(cert_path + server_host_name + '.csr'):
-            show_msg(_('Request %s not found on the client’s side') \
+            show_msg(_('Request %s not found on the client`s side') \
                             %(cert_path + server_host_name + '.csr'))
             return 1
 
